
--  Copyright (C) 2002, 2003, 2004, 2005, 2006 Balint Kis (balint@k-i-s.net)

--  This program is free software; you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation; either version 2 of the License, or
--  (at your option) any later version.

--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.

--  You should have received a copy of the GNU General Public License
--  along with this program; if not, write to the Free Software
--  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

----------------------------------------------------------
-- v2.6 to v2.7 patch
----------------------------------------------------------

-- create version control sequence and table
create sequence photo_version_id_sequence start 1;
create table photo_version (
  identifier            integer not null primary key,
  key                   integer not null,
  photo                 integer not null references photo(identifier),
  master                char(1) check (master in ('t', 'f')),
  small_image_path      varchar(500),
  medium_image_path     varchar(500),
  large_image_path      varchar(500),
  date_of_creation      timestamp,
  comment               text
);

-- populate version control table
insert into photo_version
  select (nextval('photo_version_id_sequence')), 1, identifier, 't', small_image_path, medium_image_path, large_image_path, now(), '' from photo;

-- recreate affected views
drop view view_photo;
drop view view_random_photo;

create view view_photo as
  select photo.identifier, caption, users, date_of_exposure, photo_dupe.date_of_creation,
         storage_location, storage_index,
         photo_version.small_image_path, photo_version.medium_image_path, photo_version.large_image_path,
         folder, (access_type.value) as access_rights
    from photo, photo_dupe, photo_version, access_type
   where photo.identifier = photo_version.photo
     and photo.identifier = photo_dupe.photo
     and photo.access_rights = access_type.identifier
   order by photo.identifier;

create view view_random_photo as
  select photo_version.small_image_path, photo_version.medium_image_path, photo_version.large_image_path
    from photo, photo_version
   where photo.identifier=photo_version.photo
     and photo.identifier=(select cast(random()*count_photos() as integer));


-- we rename colums first since droping was implemented only with 7.3
alter table photo rename column small_image_path  to drop_me_small_image_path;
alter table photo rename column medium_image_path to drop_me_medium_image_path;
alter table photo rename column large_image_path  to drop_me_large_image_path;

-- drop columns which aren't used any longer
alter table photo drop column drop_me_small_image_path;
alter table photo drop column drop_me_medium_image_path;
alter table photo drop column drop_me_large_image_path;

-- extend system preferences table with the current volume and upper size limit
alter table system_preferences add column current_volume varchar(500);
alter table system_preferences add column volume_max_size integer;


create function count_subfolders_by_folder(integer) returns bigint
as 'select count(identifier) from folder where parent_folder = $1' language 'sql';
create function count_subfolders_by_folder(integer, integer) returns bigint
as 'select count(identifier) from folder where parent_folder = $1 and access_rights <= $2' language 'sql';
